@@ -1391,7 +1391,7 @@ void QtTableView::paintEvent( TQPaintEvent *e )
 	TQRect r = viewR;
 	r.setLeft( xPos );
 	r.setBottom( yPos<maxY?yPos:maxY );
-	if ( inherits( TQMULTILINEEDIT_OBJECT_NAME_STRING ) )
+	if ( inherits( "TQMultiLineEdit" ) )
 	    paint.fillRect( r.intersect( updateR ), g.base() );
 	else
 	    paint.eraseRect( r.intersect( updateR ) );
@@ -1399,7 +1399,7 @@ void QtTableView::paintEvent( TQPaintEvent *e )
     if ( yPos <= maxY ) {
 	TQRect r = viewR;
 	r.setTop( yPos );
-	if ( inherits( TQMULTILINEEDIT_OBJECT_NAME_STRING ) )
+	if ( inherits( "TQMultiLineEdit" ) )
 	    paint.fillRect( r.intersect( updateR ), g.base() );
 	else
 	    paint.eraseRect( r.intersect( updateR ) );
@@ -1439,20 +1439,20 @@ TQScrollBar *QtTableView::verticalScrollBar() const
 {
     QtTableView *that = (QtTableView*)this; // semantic const
     if ( !vScrollBar ) {
-	TQScrollBar *sb = new TQScrollBar( Qt::Vertical, that );
+	TQScrollBar *sb = new TQScrollBar( TQt::Vertical, that );
 #ifndef TQT_NO_CURSOR
 	sb->setCursor( arrowCursor );
 #endif
         sb->resize( sb->sizeHint() ); // height is irrelevant
 	TQ_CHECK_PTR(sb);
 	sb->setTracking( FALSE );
-	sb->setFocusPolicy( TQ_NoFocus );
-	connect( sb, TQT_SIGNAL(valueChanged(int)),
-		 TQT_SLOT(verSbValue(int)));
-	connect( sb, TQT_SIGNAL(sliderMoved(int)),
-		 TQT_SLOT(verSbSliding(int)));
-	connect( sb, TQT_SIGNAL(sliderReleased()),
-		 TQT_SLOT(verSbSlidingDone()));
+	sb->setFocusPolicy( TQWidget::NoFocus );
+	connect( sb, TQ_SIGNAL(valueChanged(int)),
+		 TQ_SLOT(verSbValue(int)));
+	connect( sb, TQ_SIGNAL(sliderMoved(int)),
+		 TQ_SLOT(verSbSliding(int)));
+	connect( sb, TQ_SIGNAL(sliderReleased()),
+		 TQ_SLOT(verSbSlidingDone()));
 	sb->hide();
 	that->vScrollBar = sb;
 	return sb;
@@ -1470,20 +1470,20 @@ TQScrollBar *QtTableView::horizontalScrollBar() const
 {
     QtTableView *that = (QtTableView*)this; // semantic const
     if ( !hScrollBar ) {
-	TQScrollBar *sb = new TQScrollBar( Qt::Horizontal, that );
+	TQScrollBar *sb = new TQScrollBar( TQt::Horizontal, that );
 #ifndef TQT_NO_CURSOR
 	sb->setCursor( arrowCursor );
 #endif
 	sb->resize( sb->sizeHint() ); // width is irrelevant
-	sb->setFocusPolicy( TQ_NoFocus );
+	sb->setFocusPolicy( TQWidget::NoFocus );
 	TQ_CHECK_PTR(sb);
 	sb->setTracking( FALSE );
-	connect( sb, TQT_SIGNAL(valueChanged(int)),
-		 TQT_SLOT(horSbValue(int)));
-	connect( sb, TQT_SIGNAL(sliderMoved(int)),
-		 TQT_SLOT(horSbSliding(int)));
-	connect( sb, TQT_SIGNAL(sliderReleased()),
-		 TQT_SLOT(horSbSlidingDone()));
+	connect( sb, TQ_SIGNAL(valueChanged(int)),
+		 TQ_SLOT(horSbValue(int)));
+	connect( sb, TQ_SIGNAL(sliderMoved(int)),
+		 TQ_SLOT(horSbSliding(int)));
+	connect( sb, TQ_SIGNAL(sliderReleased()),
+		 TQ_SLOT(horSbSlidingDone()));
 	sb->hide();
 	that->hScrollBar = sb;
 	return sb;
