@@ -35,7 +35,7 @@ namespace Arts {
 
 class KComboBox_impl;
 class ComboBoxIntMapper :public TQObject {
-	Q_OBJECT
+	TQ_OBJECT
   
 	KComboBox_impl *impl;
 public:
