@@ -24,7 +24,7 @@
 #include "klevelmeter_template.h"
 
 class KLevelMeter_LineBars : public KLevelMeter_Template {
-   Q_OBJECT
+   TQ_OBJECT
   
 public:
 	KLevelMeter_LineBars( Arts::KLevelMeter_impl*, TQWidget* =0, long substyle=0, long count=0, Arts::Direction =Arts::BottomToTop, float _dbmin=-24, float _dbmax=6 );
