@@ -642,12 +642,12 @@ void PlayerManager::setup()
 
     m_sliderAction = action<SliderAction>("trackPositionAction");
 
-    connect(m_sliderAction, TQT_SIGNAL(signalPositionChanged(int)),
-            this, TQT_SLOT(seekPosition(int)));
-    connect(m_sliderAction->trackPositionSlider(), TQT_SIGNAL(valueChanged(int)),
-            this, TQT_SLOT(slotUpdateTime(int)));
-    connect(m_sliderAction, TQT_SIGNAL(signalVolumeChanged(int)),
-            this, TQT_SLOT(slotSetVolume(int)));
+    connect(m_sliderAction, TQ_SIGNAL(signalPositionChanged(int)),
+            this, TQ_SLOT(seekPosition(int)));
+    connect(m_sliderAction->trackPositionSlider(), TQ_SIGNAL(valueChanged(int)),
+            this, TQ_SLOT(slotUpdateTime(int)));
+    connect(m_sliderAction, TQ_SIGNAL(signalVolumeChanged(int)),
+            this, TQ_SLOT(slotSetVolume(int)));
 
     // Call this method manually to avoid warnings.
 
@@ -655,7 +655,7 @@ void PlayerManager::setup()
 
     if(outputAction) {
         setOutput(static_cast<TDESelectAction *>(outputAction)->currentText());
-        connect(outputAction, TQT_SIGNAL(activated(const TQString &)), this, TQT_SLOT(slotSetOutput(const TQString &)));
+        connect(outputAction, TQ_SIGNAL(activated(const TQString &)), this, TQ_SLOT(slotSetOutput(const TQString &)));
     }
     else
         m_player = createPlayer();
@@ -673,7 +673,7 @@ void PlayerManager::setup()
     m_player->setVolume(volume);
 
     m_timer = new TQTimer(this, "play timer");
-    connect(m_timer, TQT_SIGNAL(timeout()), this, TQT_SLOT(slotPollPlay()));
+    connect(m_timer, TQ_SIGNAL(timeout()), this, TQ_SLOT(slotPollPlay()));
 }
 
 TQString PlayerManager::randomPlayMode() const
