@@ -97,7 +97,7 @@ PassiveInfo::PassiveInfo(TQWidget *parent, const char *name) :
     // that I'll just handle the timeout myself, thank you very much.
     KPassivePopup::setTimeout(0);
 
-    connect(m_timer, TQT_SIGNAL(timeout()), TQT_SLOT(timerExpired()));
+    connect(m_timer, TQ_SIGNAL(timeout()), TQ_SLOT(timerExpired()));
 }
 
 void PassiveInfo::setTimeout(int delay)
@@ -162,14 +162,14 @@ SystemTray::SystemTray(TQWidget *parent, const char *name) : KSystemTray(parent,
     // Just create this here so that it show up in the DCOP interface and the key
     // bindings dialog.
 
-    new TDEAction(i18n("Redisplay Popup"), TDEShortcut(), TQT_TQOBJECT(this),
-                TQT_SLOT(slotPlay()), ActionCollection::actions(), "showPopup");
+    new TDEAction(i18n("Redisplay Popup"), TDEShortcut(), this,
+                TQ_SLOT(slotPlay()), ActionCollection::actions(), "showPopup");
     
     TDEPopupMenu *cm = contextMenu();
 
-    connect(PlayerManager::instance(), TQT_SIGNAL(signalPlay()), this, TQT_SLOT(slotPlay()));
-    connect(PlayerManager::instance(), TQT_SIGNAL(signalPause()), this, TQT_SLOT(slotPause()));
-    connect(PlayerManager::instance(), TQT_SIGNAL(signalStop()), this, TQT_SLOT(slotStop()));
+    connect(PlayerManager::instance(), TQ_SIGNAL(signalPlay()), this, TQ_SLOT(slotPlay()));
+    connect(PlayerManager::instance(), TQ_SIGNAL(signalPause()), this, TQ_SLOT(slotPause()));
+    connect(PlayerManager::instance(), TQ_SIGNAL(signalStop()), this, TQ_SLOT(slotStop()));
 
     action("play")->plug(cm);
     action("pause")->plug(cm);
@@ -181,7 +181,7 @@ SystemTray::SystemTray(TQWidget *parent, const char *name) : KSystemTray(parent,
 
     // Pity the actionCollection doesn't keep track of what sub-menus it has.
 
-    TDEActionMenu *menu = new TDEActionMenu(i18n("&Random Play"), TQT_TQOBJECT(this));
+    TDEActionMenu *menu = new TDEActionMenu(i18n("&Random Play"), this);
     menu->insert(action("disableRandomPlay"));
     menu->insert(action("randomPlay"));
     menu->insert(action("albumRandomPlay"));
@@ -190,7 +190,7 @@ SystemTray::SystemTray(TQWidget *parent, const char *name) : KSystemTray(parent,
     action("togglePopups")->plug(cm);
 
     m_fadeTimer = new TQTimer(this, "systrayFadeTimer");
-    connect(m_fadeTimer, TQT_SIGNAL(timeout()), TQT_SLOT(slotNextStep()));
+    connect(m_fadeTimer, TQ_SIGNAL(timeout()), TQ_SLOT(slotNextStep()));
 
     if(PlayerManager::instance()->playing())
         slotPlay();
@@ -278,8 +278,8 @@ void SystemTray::slotFadeOut()
     m_startColor = m_labels[0]->textColor();
     m_endColor = m_labels[0]->backgroundColor();
 
-    connect(this, TQT_SIGNAL(fadeDone()), m_popup, TQT_SLOT(hide()));
-    connect(m_popup, TQT_SIGNAL(mouseEntered()), this, TQT_SLOT(slotMouseInPopup()));
+    connect(this, TQ_SIGNAL(fadeDone()), m_popup, TQ_SLOT(hide()));
+    connect(m_popup, TQ_SIGNAL(mouseEntered()), this, TQ_SLOT(slotMouseInPopup()));
     m_fadeTimer->start(1500 / STEPS);
 }
 
@@ -289,7 +289,7 @@ void SystemTray::slotFadeOut()
 void SystemTray::slotMouseInPopup()
 {
     m_endColor = m_labels[0]->textColor();
-    disconnect(TQT_SIGNAL(fadeDone()));
+    disconnect(TQ_SIGNAL(fadeDone()));
 
     m_step = STEPS - 1; // Simulate end of fade to solid text
     slotNextStep();
@@ -360,8 +360,8 @@ void SystemTray::createPopup()
     m_step = 0;
 
     m_popup = new PassiveInfo(this);
-    connect(m_popup, TQT_SIGNAL(destroyed()), TQT_SLOT(slotPopupDestroyed()));
-    connect(m_popup, TQT_SIGNAL(timeExpired()), TQT_SLOT(slotFadeOut()));
+    connect(m_popup, TQ_SIGNAL(destroyed()), TQ_SLOT(slotPopupDestroyed()));
+    connect(m_popup, TQ_SIGNAL(timeExpired()), TQ_SLOT(slotFadeOut()));
 
     TQHBox *box = new TQHBox(m_popup, "popupMainLayout");
     box->setSpacing(15); // Add space between text and buttons
@@ -448,11 +448,11 @@ void SystemTray::createButtonBox(TQWidget *parent)
 
     TQPushButton *forwardButton = new TQPushButton(m_forwardPix, 0, buttonBox, "popup_forward");
     forwardButton->setFlat(true);
-    connect(forwardButton, TQT_SIGNAL(clicked()), TQT_SLOT(slotForward()));
+    connect(forwardButton, TQ_SIGNAL(clicked()), TQ_SLOT(slotForward()));
 
     TQPushButton *backButton = new TQPushButton(m_backPix, 0, buttonBox, "popup_back");
     backButton->setFlat(true);
-    connect(backButton, TQT_SIGNAL(clicked()), TQT_SLOT(slotBack()));
+    connect(backButton, TQ_SIGNAL(clicked()), TQ_SLOT(slotBack()));
 }
 
 /**
@@ -491,7 +491,7 @@ void SystemTray::addCoverButton(TQWidget *parent, const TQPixmap &cover)
     coverButton->setFixedSize(cover.size());
     coverButton->setFlat(true);
 
-    connect(coverButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotPopupLargeCover()));
+    connect(coverButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotPopupLargeCover()));
 }
 
 TQColor SystemTray::interpolateColor(int step, int steps)
@@ -540,7 +540,7 @@ void SystemTray::setToolTip(const TQString &tip, const TQPixmap &cover)
 
 void SystemTray::wheelEvent(TQWheelEvent *e)
 {
-    if(e->orientation() ==Qt::Horizontal)
+    if(e->orientation() ==TQt::Horizontal)
         return;
 
     // I already know the type here, but this file doesn't (and I don't want it
@@ -571,12 +571,12 @@ void SystemTray::wheelEvent(TQWheelEvent *e)
 void SystemTray::mousePressEvent(TQMouseEvent *e)
 {
     switch(e->button()) {
-    case Qt::LeftButton:
-    case Qt::RightButton:
+    case TQt::LeftButton:
+    case TQt::RightButton:
     default:
         KSystemTray::mousePressEvent(e);
         break;
-    case Qt::MidButton:
+    case TQt::MidButton:
         if(!rect().contains(e->pos()))
             return;
         if(action("pause")->isEnabled())
