@@ -15,14 +15,15 @@ class Mixer;
 
 class DialogSelectMaster : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
  public:
-    DialogSelectMaster(Mixer *);
+    DialogSelectMaster(Mixer *mixer);
     ~DialogSelectMaster();
+    void show(Mixer *curr_mixer);
 
  signals:
-    void newMasterSelected(int, TQString& );
+    void newMasterSelected(bool defaultMaster, int soundcard_id, const TQString &channel_id);
 
  public slots:
     void apply();
@@ -33,11 +34,13 @@ class DialogSelectMaster : public KDialogBase
     TQVBoxLayout* _layout;
     KComboBox* m_cMixer;
     TQScrollView* m_scrollableChannelSelector;
-    TQVBox *m_vboxForScrollView;
+    TQVBox *m_vboxChannels, *m_vboxForScrollView;
     TQButtonGroup *m_buttonGroupForScrollView;
+    TQRadioButton *m_defaultMaster, *m_userMaster;
     TQStringList m_mixerPKs;
 
  private slots:
+   void masterSelectionChanged(int _unused);
    void createPageByID(int mixerId);
 };
 
