@@ -97,7 +97,7 @@ KMixWindow::KMixWindow()
 	{
         hide();
 	}
-	connect( kapp, TQT_SIGNAL( aboutToQuit()), TQT_SLOT( saveSettings()) );
+	connect( kapp, TQ_SIGNAL( aboutToQuit()), TQ_SLOT( saveSettings()) );
 }
 
 
@@ -111,25 +111,25 @@ void
 KMixWindow::initActions()
 {
 	// file menu
-	KStdAction::quit( TQT_TQOBJECT(this), TQT_SLOT(quit()), actionCollection());
+	KStdAction::quit( this, TQ_SLOT(quit()), actionCollection());
 
 	// settings menu
-	KStdAction::showMenubar( TQT_TQOBJECT(this), TQT_SLOT(toggleMenuBar()), actionCollection());
-        KStdAction::preferences( TQT_TQOBJECT(this), TQT_SLOT(showSettings()), actionCollection());
-	new TDEAction( i18n( "Configure &Global Shortcuts..." ), "configure_shortcuts", 0, TQT_TQOBJECT(this),
-		TQT_SLOT( configureGlobalShortcuts() ), actionCollection(), "settings_global" );
-	KStdAction::keyBindings( guiFactory(), TQT_SLOT(configureShortcuts()), actionCollection());
+	KStdAction::showMenubar( this, TQ_SLOT(toggleMenuBar()), actionCollection());
+        KStdAction::preferences( this, TQ_SLOT(showSettings()), actionCollection());
+	new TDEAction( i18n( "Configure &Global Shortcuts..." ), "configure_shortcuts", 0, this,
+		TQ_SLOT( configureGlobalShortcuts() ), actionCollection(), "settings_global" );
+	KStdAction::keyBindings( guiFactory(), TQ_SLOT(configureShortcuts()), actionCollection());
 
-	(void) new TDEAction( i18n( "Hardware &Information" ), 0, TQT_TQOBJECT(this), TQT_SLOT( slotHWInfo() ), actionCollection(), "hwinfo" );
-	(void) new TDEAction( i18n( "Hide Mixer Window" ), Key_Escape, TQT_TQOBJECT(this), TQT_SLOT(hide()), actionCollection(), "hide_kmixwindow" );
+	(void) new TDEAction( i18n( "Hardware &Information" ), 0, this, TQ_SLOT( slotHWInfo() ), actionCollection(), "hwinfo" );
+	(void) new TDEAction( i18n( "Hide Mixer Window" ), Key_Escape, this, TQ_SLOT(hide()), actionCollection(), "hide_kmixwindow" );
 
 	m_globalAccel = new TDEGlobalAccel(this, "KMix");
 	m_globalAccel->insert( "Increase volume", i18n( "Increase Volume of Master Channel"), TQString(),
-			TDEShortcut(), TDEShortcut(), TQT_TQOBJECT(this), TQT_SLOT( slotIncreaseVolume() ) );
+			TDEShortcut(), TDEShortcut(), this, TQ_SLOT( slotIncreaseVolume() ) );
 	m_globalAccel->insert( "Decrease volume", i18n( "Decrease Volume of Master Channel"), TQString(),
-			TDEShortcut(), TDEShortcut(), TQT_TQOBJECT(this), TQT_SLOT( slotDecreaseVolume() ) );
+			TDEShortcut(), TDEShortcut(), this, TQ_SLOT( slotDecreaseVolume() ) );
 	m_globalAccel->insert( "Toggle mute", i18n( "Toggle Mute of Master Channel"), TQString(),
-			TDEShortcut(), TDEShortcut(), TQT_TQOBJECT(this), TQT_SLOT( slotToggleMuted() ) );
+			TDEShortcut(), TDEShortcut(), this, TQ_SLOT( slotToggleMuted() ) );
 	m_globalAccel->readSettings();
 	m_globalAccel->updateConnections();
 
@@ -157,7 +157,7 @@ KMixWindow::initWidgets()
 	qlbl->setFixedHeight(qlbl->sizeHint().height());
 	m_cMixer = new KComboBox( FALSE, mixerNameLayout, "mixerCombo" );
 	m_cMixer->setFixedHeight(m_cMixer->sizeHint().height());
-	connect( m_cMixer, TQT_SIGNAL( activated( int ) ), TQT_TQOBJECT(this), TQT_SLOT( showSelectedMixer( int ) ) );
+	connect( m_cMixer, TQ_SIGNAL( activated( int ) ), this, TQ_SLOT( showSelectedMixer( int ) ) );
 	TQToolTip::add( m_cMixer, i18n("Current mixer" ) );
 
 	// Add first layout to widgets
@@ -370,7 +370,7 @@ KMixWindow::showSettings()
    cfg->addPage(cfgx, i18n("Experimental"), "bug");
 #endif
 
-   connect(cfg, TQT_SIGNAL(settingsChanged()), this, TQT_SLOT(applyPrefs()));
+   connect(cfg, TQ_SIGNAL(settingsChanged()), this, TQ_SLOT(applyPrefs()));
 
    cfg->show();
 }
