@@ -27,7 +27,7 @@ class TQFile;
 class KRecFileViewWidget;
 
 class KRecFile : virtual public TQObject {
-   Q_OBJECT
+   TQ_OBJECT
   
 	friend class KRecFileWidget;
 public:
@@ -125,7 +125,7 @@ class TDEConfig;
 class TQDataStream;
 
 class KRecBuffer : virtual public TQObject {
-   Q_OBJECT
+   TQ_OBJECT
   
 public:
 	KRecBuffer( const TQString &, int, bool, KRecFile*, const char* =0 );
