@@ -27,7 +27,7 @@ class TQVBox;
 class KRecConfigFilesWidget;
 
 class KRecNewProperties : public TQDialog {
-   Q_OBJECT
+   TQ_OBJECT
   
 public:
 	KRecNewProperties( TQWidget*, const char* =0 );
