@@ -26,7 +26,7 @@ class KTempFile;
 class TQFile;
 
 class KRecExport_OGG : public KRecExportItem {
-   Q_OBJECT
+   TQ_OBJECT
   
 public:
 	KRecExport_OGG( TQObject*, const char* =0, const TQStringList& =0 );
