@@ -42,11 +42,6 @@
 #include <fcntl.h>
 #include <sys/ioctl.h>
 
-/* this is for glibc 2.x which the ust structure in ustat.h not stat.h */
-#ifdef __GLIBC__
-#include <sys/ustat.h>
-#endif
-
 #ifdef __FreeBSD__
 #include <sys/param.h>
 #include <sys/ucred.h>
@@ -114,7 +109,7 @@ TDECompactDisc::TDECompactDisc(InformationMode infoMode) :
     m_trackArtists.clear();
     m_trackTitles.clear();
     m_trackStartFrames.clear();
-    connect(&timer, TQT_SIGNAL(timeout()), TQT_SLOT(timerExpired()));
+    connect(&timer, TQ_SIGNAL(timeout()), TQ_SLOT(timerExpired()));
 }
 
 TDECompactDisc::~TDECompactDisc()
