@@ -6,7 +6,7 @@
 #include <tqdict.h>
 #include <tqstringlist.h>
 #include <cassert>
-#include <kdemacros.h>
+#include <tdemacros.h>
 
 class PlaylistItem;
 
@@ -27,7 +27,7 @@ class PlaylistItem;
  * @author Charles Samuels
  * @version 2.3
  **/
-class KDE_EXPORT PlaylistItemData
+class TDE_EXPORT PlaylistItemData
 {
 public:
 	PlaylistItemData();
@@ -205,7 +205,7 @@ private:
  * @author Charles Samuels
  * @version 2.3
  **/
-class KDE_EXPORT PlaylistItem
+class TDE_EXPORT PlaylistItem
 {
 public:
 	PlaylistItem(const PlaylistItem &source);
