@@ -9,7 +9,7 @@
 
 class Net : public TQServerSocket, public Plugin
 {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
