@@ -49,7 +49,7 @@ SafeListViewItem::SafeListViewItem(TQListView *parent, TQListViewItem *after, co
 	addRef();
 	setUrl(text);
 
-	static_cast<TDEListView*>(TQT_TQWIDGET(parent))->moveItem(this, 0, after);
+	static_cast<TDEListView*>(parent)->moveItem(this, 0, after);
 	setOn(true);
 
 	// is this really needed, it makes the listview too wide for me :(
@@ -91,7 +91,7 @@ SafeListViewItem::SafeListViewItem(TQListView *parent, TQListViewItem *after, co
 		}
 	}
 
-	static_cast<TDEListView*>(TQT_TQWIDGET(parent))->moveItem(this, 0, after);
+	static_cast<TDEListView*>(parent)->moveItem(this, 0, after);
 	modified();
 
 	if (!streamable() && enqueue(url()))
@@ -355,10 +355,10 @@ List::List(View *parent)
 	setDragEnabled(true);
 	setItemsMovable(true);
 	setSelectionMode(TQListView::Extended);
-	connect(TQT_TQOBJECT(this), TQT_SIGNAL(dropped(TQDropEvent*, TQListViewItem*)), TQT_SLOT(dropEvent(TQDropEvent*, TQListViewItem*)));
-	connect(TQT_TQOBJECT(this), TQT_SIGNAL(moved()), TQT_SLOT(move()));
-	connect(TQT_TQOBJECT(this), TQT_SIGNAL(aboutToMove()), parent, TQT_SLOT(setNoSorting()));
-	connect(TQT_TQOBJECT(this), TQT_SIGNAL(deleteCurrentItem()), parent, TQT_SLOT(deleteSelected()));
+	connect(this, TQ_SIGNAL(dropped(TQDropEvent*, TQListViewItem*)), TQ_SLOT(dropEvent(TQDropEvent*, TQListViewItem*)));
+	connect(this, TQ_SIGNAL(moved()), TQ_SLOT(move()));
+	connect(this, TQ_SIGNAL(aboutToMove()), parent, TQ_SLOT(setNoSorting()));
+	connect(this, TQ_SIGNAL(deleteCurrentItem()), parent, TQ_SLOT(deleteSelected()));
 }
 
 List::~List()
@@ -377,7 +377,7 @@ bool List::acceptDrag(TQDropEvent *event) const
 
 void List::dropEvent(TQDropEvent *event, TQListViewItem *after)
 {
-	static_cast<View*>(TQT_TQWIDGET(parent()))->setNoSorting();
+	static_cast<View*>(parent())->setNoSorting();
 	KURL::List textlist;
 	if (!KURLDrag::decode(event, textlist)) return;
 	event->acceptAction();
@@ -569,16 +569,16 @@ void List::addNextPendingDirectory()
 		currentJobURL= *pendingIt;
 		listJob= TDEIO::listRecursive(currentJobURL, false,false);
 		connect(
-				listJob, TQT_SIGNAL(entries(TDEIO::Job*, const TDEIO::UDSEntryList&)),
-				TQT_SLOT(slotEntries(TDEIO::Job*, const TDEIO::UDSEntryList&))
+				listJob, TQ_SIGNAL(entries(TDEIO::Job*, const TDEIO::UDSEntryList&)),
+				TQ_SLOT(slotEntries(TDEIO::Job*, const TDEIO::UDSEntryList&))
 			);
 		connect(
-				listJob, TQT_SIGNAL(result(TDEIO::Job *)),
-				TQT_SLOT(slotResult(TDEIO::Job *))
+				listJob, TQ_SIGNAL(result(TDEIO::Job *)),
+				TQ_SLOT(slotResult(TDEIO::Job *))
 			);
 		connect(
-				listJob, TQT_SIGNAL(redirection(TDEIO::Job *, const KURL &)),
-				TQT_SLOT(slotRedirection(TDEIO::Job *, const KURL &))
+				listJob, TQ_SIGNAL(redirection(TDEIO::Job *, const KURL &)),
+				TQ_SLOT(slotRedirection(TDEIO::Job *, const KURL &))
 			);
 		pendingAddDirectories.remove(pendingIt);
 	}
@@ -638,25 +638,25 @@ View::View(SplitPlaylist *)
 {
 	list=new List(this);
 	setCentralWidget(list);
-	connect(list, TQT_SIGNAL(modified(void)), TQT_TQOBJECT(this), TQT_SLOT(setModified(void)) );
+	connect(list, TQ_SIGNAL(modified(void)), this, TQ_SLOT(setModified(void)) );
 	// connect the click on the header with sorting
-	connect(list->header(),TQT_SIGNAL(clicked(int)),this,TQT_SLOT(headerClicked(int)) );
+	connect(list->header(),TQ_SIGNAL(clicked(int)),this,TQ_SLOT(headerClicked(int)) );
 
-	mOpen=new TDEAction(i18n("Add &Files..."), "queue", 0, TQT_TQOBJECT(this), TQT_SLOT(addFiles()), actionCollection(), "add_files");
-	(void) new TDEAction(i18n("Add Fol&ders..."), "folder", 0, TQT_TQOBJECT(this), TQT_SLOT(addDirectory()),  actionCollection(), "add_dir");
-	mDelete=new TDEAction(i18n("Delete"), "edit-delete", Key_Delete, TQT_TQOBJECT(this), TQT_SLOT(deleteSelected()),  actionCollection(), "delete");
+	mOpen=new TDEAction(i18n("Add &Files..."), "queue", 0, this, TQ_SLOT(addFiles()), actionCollection(), "add_files");
+	(void) new TDEAction(i18n("Add Fol&ders..."), "folder", 0, this, TQ_SLOT(addDirectory()),  actionCollection(), "add_dir");
+	mDelete=new TDEAction(i18n("Delete"), "edit-delete", Key_Delete, this, TQ_SLOT(deleteSelected()),  actionCollection(), "delete");
 
-	mClose=KStdAction::close(TQT_TQOBJECT(this), TQT_SLOT(close()), actionCollection());
-	mFind=KStdAction::find(TQT_TQOBJECT(this), TQT_SLOT(find()), actionCollection());
+	mClose=KStdAction::close(this, TQ_SLOT(close()), actionCollection());
+	mFind=KStdAction::find(this, TQ_SLOT(find()), actionCollection());
 
-	(void) KStdAction::configureToolbars(TQT_TQOBJECT(this), TQT_SLOT(configureToolBars()), actionCollection());
-	mOpenNew=KStdAction::openNew(TQT_TQOBJECT(this), TQT_SLOT(openNew()), actionCollection());
-	mOpenpl=KStdAction::open(TQT_TQOBJECT(this), TQT_SLOT(open()), actionCollection());
-	mSave=KStdAction::save(TQT_TQOBJECT(this), TQT_SLOT(save()), actionCollection());
-	mSaveAs=KStdAction::saveAs(TQT_TQOBJECT(this), TQT_SLOT(saveAs()), actionCollection());
+	(void) KStdAction::configureToolbars(this, TQ_SLOT(configureToolBars()), actionCollection());
+	mOpenNew=KStdAction::openNew(this, TQ_SLOT(openNew()), actionCollection());
+	mOpenpl=KStdAction::open(this, TQ_SLOT(open()), actionCollection());
+	mSave=KStdAction::save(this, TQ_SLOT(save()), actionCollection());
+	mSaveAs=KStdAction::saveAs(this, TQ_SLOT(saveAs()), actionCollection());
 
-	(void) new TDEAction(i18n("Shuffle"), "misc", 0, TQT_TQOBJECT(SPL), TQT_SLOT( randomize() ), actionCollection(), "shuffle");
-	(void) new TDEAction(i18n("Clear"), "edit-clear", 0, TQT_TQOBJECT(list), TQT_SLOT( clear() ), actionCollection(), "clear");
+	(void) new TDEAction(i18n("Shuffle"), "misc", 0, SPL, TQ_SLOT( randomize() ), actionCollection(), "shuffle");
+	(void) new TDEAction(i18n("Clear"), "edit-clear", 0, list, TQ_SLOT( clear() ), actionCollection(), "clear");
 
 	createGUI("splui.rc");
 
@@ -669,7 +669,7 @@ View::View(SplitPlaylist *)
 void View::find()
 {
 	mFinder->show();
-	connect(mFinder, TQT_SIGNAL(search(Finder*)), TQT_SLOT(findIt(Finder*)));
+	connect(mFinder, TQ_SIGNAL(search(Finder*)), TQ_SLOT(findIt(Finder*)));
 }
 
 static bool testWord(TQListViewItem *i, const TQString &finder)
@@ -797,6 +797,9 @@ void View::init()
 		list->openGlobal(internalURL);
 	}
 
+	for(PlaylistItem item = SPL->getFirst(); item; item = SPL->getAfter(item))
+	    if(item.url().path().isEmpty()) item.remove();
+
 	TDEConfig &config = *TDEGlobal::config();
 	config.setGroup("splitplaylist");
 
@@ -964,7 +967,7 @@ void View::configureToolBars()
 {
 	saveMainWindowSettings(TDEGlobal::config(), "SPL Window");
 	KEditToolbar dlg(actionCollection(), "splui.rc");
-	connect(&dlg, TQT_SIGNAL(newToolbarConfig()), TQT_SLOT(newToolBarConfig()));
+	connect(&dlg, TQ_SIGNAL(newToolbarConfig()), TQ_SLOT(newToolBarConfig()));
 	dlg.exec();
 }
 
