@@ -8,7 +8,7 @@
 #include <tqmap.h>
 
 class WaSkinManager : public TQObject, public DCOPObject {
-Q_OBJECT
+TQ_OBJECT
 //
 K_DCOP
 
